cluster_analysis_integrate_rare
cluster_analysis_integrate_rare(
raw_counts,
project_name,
resolution,
neighbors,
max_dimension,
feature_genes = NULL
)Raw count matrix (n_genes X n_cells).
Character name of the Seurat project.
Numeric value specifying the parameter resolution used in the Seurat function FindClusters.
Numeric value specifying the parameter k.param in the Seurat function FindNeighbors
Numeric value specifying the maximum number of the PCA dimensions used in the parameter dims for the Seurat function FindNeighbors
vector of features specifying the argument features in the Seurat function RunPCA.
Seurat object including raw and normalized counts matrices, UMAP coordinates and cluster result.
https://www.rdocumentation.org/packages/Seurat/versions/4.0.1/topics/FindClusters https://www.rdocumentation.org/packages/Seurat/versions/4.0.1/topics/FindNeighbors https://www.rdocumentation.org/packages/Seurat/versions/4.0.1/topics/RunPCA