merge_cluster
merge_cluster(old_cluster, new_cluster, max_number = NULL)original cluster assignment that need to be updated
new cluster assignment that need to be integrated with old_cluster.
Threshold in size for clusters in new_cluster. Only cluster with number of cells smaller than max_number will be integrated in old cluster. If max_number is NULL, then all the clusters in new_cluster are integrated in old cluster.
Numeric vector of length equal to old_cluster showing the merged cluster assignment between old cluster and new_cluster.