A white-marker is a gene whose median expression across cells belong to single_cluster is greater than threshold and in all the other clusters is equal to zero.
white_black_markers(
cluster,
single_cluster,
norm_counts,
marker_list,
threshold = 0
)Vector of length equal to the number of cells, with cluster assignment.
Character. Label of one specify cluster
Norm count matrix (genes X cells).
Third element of the output list as returned by the function markers_cluster_seurat
Numeric. The median of the genes across cells belong to single_cluster has to be greater than threshold in order to be consider as a white-black marker for single_cluster
Logical vector of length equal to marker_list, with TRUE/FALSE if the gene is/is not a white-black marker for single_cluster.